#!/usr/bin/python
#coding: UTF-8

from threading import Thread

'''
def threadTab(**kwargs):
    delay = "0"
    thread_post = threadItem
    refrac = VTGThread_refractor(thread_name = ("%s" % thread_post))
    refrac.__setattr__("delay", delay)
    refrac.__setattr__("text_intf_", text_intf_)
    refrac.__setattr__("text_intf_brief_", text_intf_brief_)
    refrac.__setattr__("butt", threadItem)
    refrac.__setattr__("dev", dev)
    refrac.__setattr__("hostName", hostName)
    refrac.__setattr__("deviceName", deviceName)
    refrac.__setattr__("deviceOrg", deviceOrg)
    refrac.__setattr__("contents", contents)
    refrac.__setattr__("ala", ala)
    return refrac

'''

#
class VTGThread_refractor(Thread):
    # 2021.1.20 refractor
    # 2020.7.4  reflection_deco
    # 2020.2.19 replace with def __init__(self, thread_name, delay, devicename, deviceorg):
    # 2020.2.14 thread adding with devicetypelist 
    #

    def __init__(self, *args, **kwargs):
        # implict self.__gNum_of_thread = 10000000
        # implict self.__delay
        # implict self.__deviceName
        # implict self.__deviceOrg
        # implict self.__iThread
        super().__init__(name = kwargs['thread_name'])





# -*- coding: utf-8 -*-
from selenium.webdriver.common.by import By
from ..base.pageobject_  import BasePageObject, WebDriverWait, EC
import pinyin
# from configini_crw import *
from cinirw.cinirw_ import *
import os
from ...director.misc_ import secit

class VisitFlowObject(BasePageObject):

    __visit_loc = (By.ID, "sb_form_q")
    __btn_loc = (By.ID, "sb_form_go")

    __visit_loc_pass_ = (By.ID, "inputPassword")
    __visit_loc_email_ = (By.ID, "inputEmail")
    __btn_loc_css_ = (By.CSS_SELECTOR, "body > div > div > div > section > div > form > div.control-group.margin-b > div > button")


    map_input_localvalueID = (By.ID, 'localvalue')
    map_click_localsearchID = (By.ID, 'localsearch')
    map_click_selectorCSS = (By.CSS_SELECTOR, '#no_0')
    map_get_selectorXPATH = (By.XPATH, '//*[@id="no_0"]/p')
    map_get_cityID = (By.ID, 'curCity')


    def fetch_text_(self, visittype):
        fetched_ = self.locate_element(*visittype)
        return fetched_

    def scan_g_class_(self, visittype):
        ''' Locate Scan G '''
        g_class_ = self.locate_element(*visittype)
        g_class_x_loc_ = (By.CSS_SELECTOR, 'text')
        x = g_class_.find_elements_by_css_selector('text')
        print()
        if (len(x) > 0):
            for y in x:
                print(y.text)
                print(y.get_attribute('x'))
                #print(dir(y))

    def select_ui_class_(self, visittype, Internet):
        ''' Locate Select UI LI '''
        ui_class_ = self.locate_element(*visittype)
        t = ui_class_.find_elements_by_xpath('li')
        if (len(t) > 0):
            for u in t:
                # print(u.get_attribute('data-value'))
                if (Internet == u.get_attribute('data-value')):
                    u.click()
                    break

    def scan_ui_class_(self, visittype):
        ''' Locate Scan UI LI '''
        ui_class_ = self.locate_element(*visittype)
        t = ui_class_.find_elements_by_xpath('li')
        if (len(t) > 0):
            for u in t: # print(u.get_attribute('class'))
                print(u.get_attribute('data-value'))

    def btn_dclick_visittype_(self, visittype):
        ''' Locate Button '''
        FlowBtn = self.locate_element(*visittype)
        FlowBtn.click()
        FlowBtn.click()

    def btn_click_visittype_(self, visittype):
        ''' Locate Button '''
        FlowBtn = self.locate_element(*visittype)
        FlowBtn.click()

    def flow_content_visittype_(self, content, visittype):
        FlowContent = self.locate_element(*visittype)
        FlowContent.send_keys(content)

    def flow_content(self, content):
        ''' Locate Input '''
        FlowContent = self.locate_element(*self.__visit_loc)
        FlowContent.send_keys(content)

    def btn_click(self):
        ''' Locate Button '''
        FlowBtn = self.locate_element(*self.__btn_loc_css_)
        FlowBtn.click()

    def flow_content_pass_(self, content):
        ''' Locate Input '''
        FlowContent = self.locate_element(*self.__visit_loc_pass_)
        FlowContent.send_keys(content)

    def flow_content_email_(self, content):
        ''' Locate Input '''
        FlowContent = self.locate_element(*self.__visit_loc_email_)
        FlowContent.send_keys(content)



def visitVersa_():
    Versa = VisitFlowObject()
    Versa.visit("https://172.17.21.1/versa/login/")
    # BSearch.flow_content_pass_("Linshi@123")
    # BSearch.flow_content_email_("Linshi")
    visit_loc_pass_ = (By.ID, "inputPassword")
    visit_loc_email_ = (By.ID, "inputEmail")
    Versa.flow_content_visittype_("Linshi@123", visit_loc_pass_)
    Versa.flow_content_visittype_("Linshi", visit_loc_email_)
    Versa.btn_click()
    Versa.quit()


def visitBing_():
    Bing = VisitFlowObject()
    Bing.visit("https://cn.bing.com/")
    # BSearch.flow_content("tsunx")
    # BSearch.btn_click()
    visit_loc = (By.ID, "sb_form_q")
    btn_loc = (By.ID, "sb_form_go")
    Bing.flow_content_visittype_("Python Selenium", visit_loc)
    Bing.btn_click_visittype_(btn_loc)
    Bing.quit()


def visitLinkAvailability_(tenant):
    Versa = VisitFlowObject()
    Versa.visit("https://211.152.44.186/versa/login")
    visit_loc_pass_ = (By.ID, "inputPassword")
    visit_loc_email_ = (By.ID, "inputEmail")
    Versa.flow_content_visittype_("Versa#21viacloud", visit_loc_pass_)
    Versa.flow_content_visittype_("Administrator", visit_loc_email_)
    Versa.btn_click()

    # visit Analytics
    # //*[@id="menuContainer"]/li[6]/a
    visit_loc_analytics_ = (By.XPATH, r'//*[@id="menuContainer"]/li[6]/a')
    Versa.btn_click_visittype_(visit_loc_analytics_)

    # visit Sites
    # #left-nav-analytics-sd-wan > li:nth-child(1) > a > span
    visit_loc_sites_ = (By.CSS_SELECTOR, '#left-nav-analytics-sd-wan > li:nth-child(1) > a > span')
    Versa.btn_click_visittype_(visit_loc_sites_)

    # visit Link Availability
    # //*[@id="2"]/a
    visit_loc_LA_ = (By.XPATH, '//*[@id="2"]/a')
    Versa.btn_dclick_visittype_(visit_loc_LA_)

    # visit Tenant
    # //*[@id="1"]/div/div/span
    # visit_loc_Tn_ = (By.XPATH, '//*[@id="1"]/div/div/span')
    # Versa.btn_click_visittype_(visit_loc_Tn_)
    # Select(driver.find_element_by_id('vlanData_0-0_networkName')).select_by_visible_text('Internet')
    # //*[@id="1"]/div/div/ul
    # #\31  > div > div > span
    # //*[@id="1"]/div/div/span

    # search by tenant
    visit_loc_searchbytenant_ = (By.XPATH, '//*[@id="1"]/div/div/span')
    Versa.btn_click_visittype_(visit_loc_searchbytenant_)
    visit_loc_tenants_ = (By.CSS_SELECTOR, '.typeahead.typeahead-long.dropdown-menu')
    ## Versa.scan_ui_class_(visit_loc_tenants_)
    #Versa.select_ui_class_(visit_loc_tenants_, "Customer-YiMeng")
    #Versa.select_ui_class_(visit_loc_tenants_, "Customer-JinQiaoZhen")
    Versa.select_ui_class_(visit_loc_tenants_, tenant)

    # tenant LA detail
    visit_loc_LA_devices_ = (By.CSS_SELECTOR, 'g.highcharts-axis-labels.highcharts-xaxis-labels')
    print("-- The Result -- \n")
    Versa.scan_g_class_(visit_loc_LA_devices_)
    # #highcharts-4w1hxf8-1540 > svg > g.highcharts-axis-labels.highcharts-xaxis-labels > text:nth-child(2)
    Versa.quit()

@secit()
def visitAPIMAP(cmaddress):
    Map = VisitFlowObject()
    Map.visit("http://api.map.baidu.com/lbsapi/getpoint/index.html")
    Map.flow_content_visittype_(cmaddress, VisitFlowObject.map_input_localvalueID)
    Map.btn_click_visittype_(VisitFlowObject.map_click_localsearchID)
    Map.btn_click_visittype_(VisitFlowObject.map_click_selectorCSS)
    points2 = Map.fetch_text_(VisitFlowObject.map_get_selectorXPATH)
    # print(points2.text.split("\n"))
    if (2 == len(points2.text.split("\n"))):
        device_address, device_location = points2.text.split("\n")
    else:
        device_address, device_phone, device_location = points2.text.split("\n")
    # device_location_str, device_locations = device_location.split(('：').decode("utf8","ignore"))
    device_location_str, device_locations = device_location.split(u"：")
    longitude, latitude = device_locations.split(",")
    print("latitude: ", latitude)
    print("longitude: ", longitude)
    #
    # fetched cmaddress
    device_addresses_str, device_addresses = device_address.split(u"：")
    print(device_addresses_str)
    print(device_addresses)
    currentAddrPinyin = ""
    for item in device_addresses:
        currentAddrPinyin += pinyin.get(item, format = 'strip')[:].capitalize()
        # print(item)
        # subCurrentAddrPinyin = pinyin.get(item, format = 'strip')[:].capitalize()
        # currentAddrPinyin += subCurrentAddrPinyin
    print(currentAddrPinyin)
    #
    # fetch city
    # currentCity = driver.find_element_by_id('curCity')
    currentCity = Map.fetch_text_(VisitFlowObject.map_get_cityID)
    currentCityText = str(currentCity.text)
    currentCityPinyin = pinyin.get(currentCityText, format = 'strip')[:-3].capitalize()
    print(currentCity.text)
    print(currentCityPinyin)
    # save the fetched
    ROOT = '..\\Devices'
    # pathd_put = ".\\" + ROOT + "\\" + "config_devices_pst_" + device_address + ".ini"
    pathd_put = '.{}{}{}config_branch_locinfo_{}_.ini'.format(os.sep, ROOT, os.sep, device_address)
    print(pathd_put)
    UpdateConfigIni = WriteConfigIni(pathd_put)
    UpdateConfigIni.addConfigSection("LocationInformation")
    UpdateConfigIni.putConfigValue("LocationInformation", "ChineseMadrineAddress", device_address)
    UpdateConfigIni.putConfigValue("LocationInformation", "Address1", str(currentAddrPinyin))
    # 2020.1.13 xpinyin
    UpdateConfigIni.putConfigValue("LocationInformation", "city", str(currentCityPinyin))
    UpdateConfigIni.putConfigValue("LocationInformation", "country", "CHINA")
    UpdateConfigIni.putConfigValue("LocationInformation", "Latitude", latitude)
    UpdateConfigIni.putConfigValue("LocationInformation", "Longitude", longitude)
    #
    Map.quit()









            







# !/usr/bin/env python
# -*- coding: utf-8 -*-

import platform
from time import sleep
import sys, traceback

import argparse
from iTude.aopom.chuanbei.visit.flowobject_ import visitAPIMAP

def server_list_object_pickup(name):
    HERE = pathlib.Path(__file__).parent.parent
    buf = ( HERE / "__init__.py" ).read_text()
    slo1 = buf.find(name) + len(f"{name} = ")
    slo2 = buf[slo1:].find("]") + 1
    slo_ = buf[slo1:slo1 + slo2]
    p1 = re.compile("'(.*?)'", re.S)
    return (re.findall(p1, slo_))


def get_platform():
    return platform.platform()


def get_node():
    return platform.node()


def maintude(args):
    print("")
    print("--cmaddress {0}".format(args.cmaddress))


def itude_app():
    parser = argparse.ArgumentParser(usage="it's usage on the chinesemadrine address port.", description="help info.")
    parser.add_argument("-C", "--cmaddress", default="cmaddress", help="the chinese madrine address input.")
    args = parser.parse_args()
    maintude(args)
    print(args.cmaddress)
    visitAPIMAP(args.cmaddress)






#!/usr/bin/python
#coding: UTF-8

from threading import Thread

#
class VTGThread_refractor_sub(Thread):
    # 2021.1.22 refractor_sub
    # 2021.1.20 refractor
    # 2020.7.4  reflection_deco
    # 2020.2.19 replace with def __init__(self, thread_name, delay, devicename, deviceorg):
    # 2020.2.14 thread adding with devicetypelist 
    #

    def __init__(self, *args, **kwargs):
        # implict self.__gNum_of_thread = 10000000
        # implict self.__delay
        # implict self.__deviceName
        # implict self.__deviceOrg
        # implict self.__iThread
        super().__init__(name = kwargs['thread_name'])





#!/usr/bin/python
#coding: UTF-8

import threading

#vtg_reflection_deco_ = []
#vtg_reflection_deco_set = set()

#
class VTGThread_reflectionDeco(threading.Thread):
    # 2020.7.4  reflection_deco
    # 2020.2.19 replace with def __init__(self, thread_name, delay, devicename, deviceorg):
    # 2020.2.14 thread adding with devicetypelist 
    #

    def __init__(self, *args, **kwargs):
        super().__init__(name = kwargs['thread_name'])



# -*- coding: utf-8 -*-
from time import sleep
from selenium import webdriver
from selenium.webdriver.support.ui import WebDriverWait
from selenium.webdriver.support import expected_conditions as EC

from selenium.webdriver.chrome.options import Options
chrome_options = Options()
chrome_options.add_argument('--headless')
chrome_options.add_argument('--disable-gpu')
chrome_options.add_argument('--incognito')
chrome_options.add_argument('--disable-infobars')


class BasePageObject():

    def __init__(self):
        self.__driverpath = "E:\\ProgramData\\Anaconda3\\chromedriver.exe"
        try:
            # self.driver = webdriver.Chrome(self.__driverpath)
            self.driver = webdriver.Chrome(self.__driverpath, chrome_options = chrome_options)
        except Exception:
            raise NameError("Not Chrome")


    def visit(self, url):
        if url != "":
            self.driver.get(url)
            self.driver.maximize_window()
            self.driver.implicitly_wait(4)
        else:
            raise ValueError("Please fetch a url path")


    def locate_element(self, *loc):
        try:
            #
            WebDriverWait(self.driver, 60, 0.1).until(EC.visibility_of_element_located(loc))
            ##return self.driver.find_element(*loc)
            ##return WebDriverWait(driver, 60, 0.1).until(EC.presence_of_element_located((By.XPATH, workflows_xpath)))
            return WebDriverWait(self.driver, 60, 0.1).until(EC.presence_of_element_located(loc))
        except:
            # print(f' {self} On page, not found element{loc} ')
            print('{} On page, not found element {}'.format(self, loc))


    def send_keys(self, loc, value, clear_first = True, click_first = True):
        try:
            loc = getattr(self, "_%s" % loc)
            if click_first:
                self.locate_element(*loc).click()
            if click_first:
                self.locate_element(*loc).clear()
                self.locate_element(*loc).send_keys(value)
        except AttributeError:
            # print(f' {self} On page, not found element{loc} ')
            print('{} On page, not found element {}'.format(self, loc))


    def quit(self):
        self.driver.implicitly_wait(60)
        self.driver.quit()



            







#!/usr/bin/python
#coding: UTF-8

import requests
from requests.adapters import HTTPAdapter
from collections import Counter

# 2021.6.22 multi-URL with weight update
# 2021.6.21 LIYUAN update
# 2021.4.2 Hyper Bound Query Director
class LIYUANDirector:
    def __init__(self, URL, AUTH, PORT):
        self.__auth = AUTH
        self.__port = PORT
        self.__urlw = Counter(URL)

    def __call__(self, func):
        def inner_wrapper(*args, **kwargs):
            # print("[ LIYUANDirector %s ] %s" % (self.__url, self.__auth, self.__port))
            # print(args, kwargs)
            # 2021.6.21 session update into director
            # 2021.1.20 session retries(4), timeout(8)
            maxRetries = 4
            timeOut = 8
            sess = requests.Session()
            sess.mount('http://', HTTPAdapter(max_retries = maxRetries))
            sess.mount('https://', HTTPAdapter(max_retries = maxRetries))
            # BASE_URL = self.__url + ":" + self.__port
            try:
                sess.get(url = "https://" + self.__urlw.most_common(1)[0][0] + ":" + self.__port, timeout = timeOut, verify = False)
            except requests.exceptions.ConnectionError as e:
                print('fail to connect, this {} could be blocked or delay'.format(self.__urlw.most_common(1)[0][0]))
                self.__urlw.subtract([self.__urlw.most_common(1)[0][0]])
            kwargs['url'] = "https://" + self.__urlw.most_common(1)[0][0]
            kwargs['auth'] = self.__auth
            kwargs['port'] = self.__port
            print('connectable {}'.format(kwargs['url']))
            return func(*args, **kwargs)
        return inner_wrapper

    @property
    def url(self):
        return self.__url
    @url.setter
    def url(self, URL):
        self.__url = URL
    @url.deleter
    def url(self):
        del self.__url

    @property
    def auth(self):
        return self.__auth
    @auth.setter
    def auth(self, AUTH):
        self.__auth = AUTH
    @auth.deleter
    def auth(self):
        del self.__auth

    @property
    def port(self):
        return self.__port
    @port.setter
    def port(self, PORT):
        self.__port = PORT
    @port.deleter
    def port(self):
        del self.__port

#




import pathlib
from setuptools import setup, find_packages

# The directory containing this file
HERE = pathlib.Path(__file__).parent

# The text of the README file
README = (HERE / "README.txt").read_text()

buf = (HERE / "iTude/__init__.py").read_text()
loc1 = buf.find('__version__') + len('__version__')
loc2 = buf[loc1:].find("'") + 1
loc3 = buf[loc1+loc2:].find("'")
VERSION = buf[loc1+loc2:loc1+loc2+loc3]
print(VERSION)

setup(
    name = "iTude",
    version = VERSION,
    author = "Chaoqun Chen",
    author_email = "chen.chaoqun.ext@99cloud.net",
    description = "A Tool for Attitude Longitude of Site (Mute)",
    long_description = README,
    long_description_content_type = "text/markdown",
    url = "https://github.com/chenchaotsun/scripts",
    license = "GNU General Public License v3.0",
    project_urls = {
        "Bug Tracker": "https://github.com/pypa/sampleproject/issues",
    },
    classifiers = [
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: GNU General Public License v3 (GPLv3)",
        "Operating System :: OS Independent",
    ],
    keywords = 'attitude_longitude',
    packages = ["iTude"],
    include_package_data = True,
    install_requires = [],
    python_requires = ">=3.6",
)



#!/usr/bin/python
#coding: UTF-8
import datetime

def secit():
    """
    Count the function in seconds
    """
    def wrapper(func):
        def inner_wrapper(*args, **kwargs):
            #start = time.clock()
            sT = datetime.datetime.now()
            func(*args, **kwargs)
            eT = datetime.datetime.now()
            print('{} sec'.format((eT - sT)))
            #end = time.clock()
            #print('used: {}'.format(end - start))
        return inner_wrapper
    return wrapper




#!/usr/bin/python
#coding: UTF-8


# 2021.1.3 Hyper Bound Query Director
class HBQDirector:
    def __init__(self, URL, AUTH, PORT):
        self.__url = URL
        self.__auth = AUTH
        self.__port = PORT

    def __call__(self, func):
        def inner_wrapper(*args, **kwargs):
            #print("[HBQDirector %s ] %s" % (self.__url, self.__auth, self.__port))
            kwargs['url'] = self.__url
            kwargs['auth'] = self.__auth
            kwargs['port'] = self.__port
            return func(*args, **kwargs)
        return inner_wrapper

    @property
    def url(self):
        return self.__url
    @url.setter
    def url(self, URL):
        self.__url = URL
    @url.deleter
    def url(self):
        del self.__url

    @property
    def auth(self):
        return self.__auth
    @auth.setter
    def auth(self, AUTH):
        self.__auth = AUTH
    @auth.deleter
    def auth(self):
        del self.__auth

    @property
    def port(self):
        return self.__port
    @port.setter
    def port(self, PORT):
        self.__port = PORT
    @port.deleter
    def port(self):
        del self.__port

#

